==> jc-1.4.0.tar.gz: polyglot/lex/EOF.h <==
// public class polyglot.lex.EOF

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5295b5fbf84545f2 polyglot_lex_EOF
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_EOF_H_
#define _JC_polyglot_lex_EOF_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_EOF$sub_refs	_jc_polyglot_lex_EOF$sub_refs;
typedef struct _jc_polyglot_lex_EOF$sub_nonrefs	_jc_polyglot_lex_EOF$sub_nonrefs;
typedef struct _jc_polyglot_lex_EOF$refs	_jc_polyglot_lex_EOF$refs;
typedef struct _jc_polyglot_lex_EOF$nonrefs	_jc_polyglot_lex_EOF$nonrefs;
typedef struct _jc_polyglot_lex_EOF$object	_jc_polyglot_lex_EOF$object;

typedef const struct _jc_polyglot_lex_EOF$vmethods	_jc_polyglot_lex_EOF$vmethods;
typedef const struct _jc_polyglot_lex_EOF$vtable	_jc_polyglot_lex_EOF$vtable;
typedef const struct _jc_polyglot_lex_EOF$vtype	_jc_polyglot_lex_EOF$vtype;

// Constructors
extern void _jc_polyglot_lex_EOF$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_EOF$object *, struct _jc_polyglot_util_Position$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_EOF$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_EOF$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_EOF$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_EOF$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_EOF$object *);
};

// Vtable
struct _jc_polyglot_lex_EOF$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_EOF$vmethods	polyglot_lex_EOF;
};

// Vtype
struct _jc_polyglot_lex_EOF$vtype {
	_jc_type			type;
	_jc_polyglot_lex_EOF$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_EOF$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_EOF$refs {
    _jc_polyglot_lex_EOF$sub_refs	polyglot_lex_EOF;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_EOF$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_EOF$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_EOF$sub_nonrefs	polyglot_lex_EOF;
};

// Object instance structure
struct _jc_polyglot_lex_EOF$object {
	_jc_polyglot_lex_EOF$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_EOF$vtype	*vtype;
	_jc_polyglot_lex_EOF$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_EOF$vtype _jc_polyglot_lex_EOF$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_EOF, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_EOF$class_object;

#endif	/* _JC_polyglot_lex_EOF_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/EOF.h <==
// public class polyglot.lex.EOF

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5295b5fbf84545f2 polyglot_lex_EOF
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_EOF_H_
#define _JC_polyglot_lex_EOF_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_EOF$sub_refs	_jc_polyglot_lex_EOF$sub_refs;
typedef struct _jc_polyglot_lex_EOF$sub_nonrefs	_jc_polyglot_lex_EOF$sub_nonrefs;
typedef struct _jc_polyglot_lex_EOF$refs	_jc_polyglot_lex_EOF$refs;
typedef struct _jc_polyglot_lex_EOF$nonrefs	_jc_polyglot_lex_EOF$nonrefs;
typedef struct _jc_polyglot_lex_EOF$object	_jc_polyglot_lex_EOF$object;

typedef const struct _jc_polyglot_lex_EOF$vmethods	_jc_polyglot_lex_EOF$vmethods;
typedef const struct _jc_polyglot_lex_EOF$vtable	_jc_polyglot_lex_EOF$vtable;
typedef const struct _jc_polyglot_lex_EOF$vtype	_jc_polyglot_lex_EOF$vtype;

// Constructors
extern void _jc_polyglot_lex_EOF$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_EOF$object *, struct _jc_polyglot_util_Position$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_EOF$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_EOF$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_EOF$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_EOF$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_EOF$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_EOF$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_EOF$vmethods	polyglot_lex_EOF;
};

// Vtype
struct _jc_polyglot_lex_EOF$vtype {
	_jc_type			type;
	_jc_polyglot_lex_EOF$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_EOF$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_EOF$refs {
    _jc_polyglot_lex_EOF$sub_refs	polyglot_lex_EOF;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_EOF$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_EOF$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_EOF$sub_nonrefs	polyglot_lex_EOF;
};

// Object instance structure
struct _jc_polyglot_lex_EOF$object {
	_jc_polyglot_lex_EOF$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_EOF$vtype	*vtype;
	_jc_polyglot_lex_EOF$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_EOF$vtype _jc_polyglot_lex_EOF$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_EOF, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_EOF$class_object;

#endif	/* _JC_polyglot_lex_EOF_H_ */
